@@ -76,11 +76,11 @@ public:
      * See saveAs for clarification*/
     KAutoSaveFile            *m_autosave;
 
-    bool                      m_dirty;                ///<dirty bit
-    bool                      m_isReadOnly;
+    bool                      m_dirty;                ///< dirty bit
+    bool                      m_isReadOnly;	      ///< FileOpenReadOnly was used for opening
 
     // save these to document
-    QList<KEduVocIdentifier>  m_identifiers;          ///<list of identifiers
+    QList<KEduVocIdentifier>  m_identifiers;          ///< list of identifiers
 
     QList<int>                m_extraSizeHints;       ///< unused
     QList<int>                m_sizeHints;            ///< unused
@@ -258,7 +258,7 @@ KEduVocDocument::ErrorCode KEduVocDocument::open( const KUrl& url,  FileHandling
 
     if (!d->m_isReadOnly) {
 	autosaveError = d->initializeKAutoSave( *d->m_autosave,  temporaryFile, flags );
-	if ( autosaveError != NoError) {
+	if (autosaveError != NoError) {
 	    return autosaveError;
 	}
     }
@@ -298,8 +298,12 @@ void KEduVocDocument::close()
 }
 
 /// @todo When the API major version number increments remove this function
-int KEduVocDocument::saveAs( const KUrl & url, FileType ft, const QString & generator )
+int KEduVocDocument::saveAs(const KUrl &url, FileType ft, const QString &generator)
 {
+    if (!d->m_isReadOnly) {
+	return FileIsReadOnly;
+    }
+
     const QString oldgenerator( d->m_generator );
     d->m_generator = generator;
 
